@@ -834,18 +834,18 @@ class ContainerSetting(Entity):
         self,
         container_name: Name,
         container_image: DockerImageName,
-        env_vars: Optional[ContainerEnvDict],
-        command: Optional[ContainerCommand],
-        args: Optional[ContainerArgs],
-        image_pull_policy: Optional[ImagePullPolicy],
-        working_dir: Optional[Path],
-        volume_mount: Optional[List[VolumeMount]],
-        security_context: Optional[PodSecurityContext],
-        limits: Optional[PodResourceDict],
-        requests: Optional[PodResourceDict],
-        readiness_probe: Optional[Probe],
-        liveness_probe: Optional[Probe],
-        ports: Optional[List[ContainerPort]]
+        env_vars: Optional[ContainerEnvDict]=None,
+        command: Optional[ContainerCommand]=None,
+        args: Optional[ContainerArgs]=None,
+        image_pull_policy: Optional[ImagePullPolicy]=ImagePullPolicy('Always'),
+        working_dir: Optional[Path]=None,
+        volume_mount: Optional[List[VolumeMount]]=None,
+        security_context: Optional[PodSecurityContext]=None,
+        limits: Optional[PodResourceDict]=None,
+        requests: Optional[PodResourceDict]=None,
+        readiness_probe: Optional[Probe]=None,
+        liveness_probe: Optional[Probe]=None,
+        ports: Optional[List[ContainerPort]]=None
     ):
         self.container_name = container_name
         self.container_image = container_image
@@ -869,7 +869,7 @@ class JobSetting(Entity):
         namespace_name: Name,
         labels: LabelDict,
         containers: List[ContainerSetting],
-        init_containers: Optional[List[ContainerSetting]],
+        init_containers: Optional[List[ContainerSetting]]=None,
         parallelism: Number = Number(1),
         ttl_seconds_after_finished: Number = Number(600),
         restart_policy: RestartPolicy = RestartPolicy('Never'),
