@@ -20,6 +20,7 @@ from .do import (
     NodeUserSettingDO,
     PodContainerDO,
     PodDO,
+    PodLogSettingDO,
     PodOSSOperationInfoDO,
     ResourceOSSSettingDO,
     SecretDO,
@@ -330,14 +331,13 @@ class K3SController:
     def get_pod_log(
         self, 
         cluster_name:str,
-        namespace_name:str,
-        pod_name:str,
-        tail_lines:int,
+        pod_log_setting: PodLogSettingDO,
         timeout:int=10
     ):
+        data = json.dumps(pod_log_setting.to_json())
         response=requests.get(
-            f'{self.url}/log/cluster_name/{cluster_name}/namespace_name/{namespace_name}/pod_name/{pod_name}/tail_lines/{tail_lines}', 
-            headers=self.header, timeout=timeout)
+            f'{self.url}/log/cluster_name/{cluster_name}', 
+            headers=self.header, data=data,timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
         return info
