@@ -12,6 +12,7 @@ from .converter import(
     JobSettingConverter,
     NodeInfoConverter,
     PodContainerConverter,
+    PodLogSettingConverter,
 )
 from ..domain.repository import(
     K3SRepository,
@@ -25,6 +26,7 @@ from ..domain.entity import (
     Namespace,
     Deployment,
     Ingress,
+    PodLogSetting,
     PodOSSOperationInfo,
     ConfigMap,
     CommandResult,
@@ -89,6 +91,7 @@ instance_info_converter = InstanceInfoConverter()
 instance_type_with_status_converter = InstanceTypeWithStatusConverter()
 job_converter = JobConverter()
 job_setting_converter = JobSettingConverter()
+pod_log_setting_converter = PodLogSettingConverter()
 
 
 class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
@@ -486,15 +489,11 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
     def get_pod_log(
         self, 
         cluster_name: Name, 
-        namespace_name: Name, 
-        pod_name: Name, 
-        tail_lines: Integer = Integer(500)
+        pod_log_setting: PodLogSetting
     ) -> Optional[str]:
         cluster_name = cluster_name.get_value()
-        namespace_name = namespace_name.get_value()
-        pod_name = pod_name.get_value()
-        tail_lines = tail_lines.get_value()
-        result = self.ao.get_pod_log(cluster_name, namespace_name, pod_name, tail_lines)
+        pod_log_setting = pod_log_setting_converter.to_do(pod_log_setting)
+        result = self.ao.get_pod_log(cluster_name, pod_log_setting)
         if result.succeed and result.get_value() is not None:
             return result.get_value()
         else:
